pycocoa.screens

Package pycocoa :: Module screens |
[frames] | no frames]

# Module screens

Types Frame and Screen, wrapping ObjC `NSScreen`.

Version: 25.04.03

Classes
| Frame A screen frame, wrapping ObjC NSRect_t.
| Screen Screen Python Type, wrapping ObjC NSRect_t.

Variables
| __all__ = `_ALL_LAZY.screens`
| Screens = `(Screen(NSScreen, name='BuiltIn'), Screen(NSScreen, `...`` An Adict of all available screens or monitors.
| Screens.BuiltIn Get the BuiltIn screen (`Screen`).
| Screens.External Get an External screen (`Screen`) or `None`.

Variables Details

  ### Screens An Adict of all available screens or monitors. Value:
      (Screen(NSScreen, name='BuiltIn'), Screen(NSScreen, name='External'))